@@ -2,20 +2,23 @@
 
 # This script must be called from the docs/ folder of the sdk repository.
 #
-# This script depends on having hugo in your system.
+# This script depends on having hugo in your system. It has been tested with
+# v0.152.2 of hugo-extended.
 
 set -e
 set -x
 
 # Download theme
 
-if [ ! -d themes/hugo-geekdoc ]; then
-    mkdir -p themes/hugo-geekdoc
-    wget https://github.com/thegeeklab/hugo-geekdoc/releases/latest/download/hugo-geekdoc.tar.gz
-    tar -xzvf hugo-geekdoc.tar.gz -C themes/hugo-geekdoc --strip-components=1
+if [ ! -d themes/hextra ]; then
+    cd themes
+    git clone https://codeberg.org/blocksds/hextra --depth=1
+    cd hextra
+    git checkout 9466af337f3a54e77b68c9852a568b79038ff0ef
+    cd ../..
 fi
 
-hugo --cleanDestinationDir --baseURL https://blocksds.skylyrac.net/docs/
+hugo --cleanDestinationDir --baseURL https://blocksds.skylyrac.net/
 
 pushd ../libs/libnds
 make docs
@@ -41,3 +44,8 @@ pushd ../libs/maxmod
 make docs
 popd
 mv ../libs/maxmod/docs/html public/maxmod
+
+pushd ../tools/grit
+make docs
+popd
+mv ../tools/grit/docs/html public/grit
