@@ -19,7 +19,6 @@ int main(int argc, char *argv[])
 
     glEnable(GL_TEXTURE_2D);
     glEnable(GL_ANTIALIAS);
-    glEnable(GL_BLEND);
 
     // Setup the rear plane
     glClearColor(0, 0, 0, 0); // Set BG to black
@@ -39,8 +38,6 @@ int main(int argc, char *argv[])
             swiWaitForVBlank();
     }
 
-    glMaterialShinyness();
-
     // Set material properties
     glMaterialf(GL_AMBIENT, RGB15(8, 8, 8));
     glMaterialf(GL_DIFFUSE, RGB15(24, 24, 24));
